@@ -63,6 +63,7 @@ import jakarta.ws.rs.client.ResponseProcessingException;
 import jakarta.ws.rs.client.WebTarget;
 import jakarta.ws.rs.container.ResourceContext;
 import jakarta.ws.rs.core.Context;
+import jakarta.ws.rs.core.Cookie;
 import jakarta.ws.rs.core.Feature;
 import jakarta.ws.rs.core.FeatureContext;
 import jakarta.ws.rs.core.GenericEntity;
@@ -159,7 +160,7 @@ public class JAXRS20ClientServerBookTest extends AbstractBusClientServerTestBase
         final ThreadMXBean threadMXBean = ManagementFactory.getThreadMXBean();
         final AtomicLong httpClientThreads = new AtomicLong(); 
 
-        final Supplier<Long> captureHttpClientThreads = () ->
+        final Supplier<Long> captureHttpClientSelectorThreads = () ->
             Arrays
                 .stream(threadMXBean.getAllThreadIds())
                 .mapToObj(id -> threadMXBean.getThreadInfo(id))
@@ -168,8 +169,16 @@ public class JAXRS20ClientServerBookTest extends AbstractBusClientServerTestBase
                 .filter(t -> t.getThreadName().endsWith("-SelectorManager"))
                 .count();
 
+        final Supplier<Long> captureHttpClientThreads = () ->
+            Arrays
+                .stream(threadMXBean.getAllThreadIds())
+                .mapToObj(id -> threadMXBean.getThreadInfo(id))
+                .filter(Objects::nonNull)
+                .filter(t -> t.getThreadName().startsWith("HttpClient-"))
+                .count();
+
         // Capture the number of client threads at start
-        final long expectedHttpClientThreads = captureHttpClientThreads.get();
+        final long expectedHttpClientSelectorThreads = captureHttpClientSelectorThreads.get();
         final Collection<WebClient> clients = new ArrayList<>();
         try {
             final String target = "http://localhost:" + PORT + "/bookstore/genericbooks/123";
@@ -194,7 +203,12 @@ public class JAXRS20ClientServerBookTest extends AbstractBusClientServerTestBase
         } finally {
             pool.shutdown();
             assertThat(pool.awaitTermination(1, TimeUnit.MINUTES), is(true));
-            assertThat(captureHttpClientThreads.get(), greaterThan(0L));
+            // Since JDK-27, HttpClient selector thread is a virtual thread by default
+            if (Runtime.version().feature() >= 27) {
+                assertThat(captureHttpClientSelectorThreads.get(), equalTo(0L));
+            } else {
+                assertThat(captureHttpClientSelectorThreads.get(), greaterThan(0L));
+            }
             assertThat(httpClientThreads.get(), greaterThan(0L));
             assertThat(httpClientThreads.get(), lessThan(150L)); /* a bit higher that pool size */
         }
@@ -203,7 +217,7 @@ public class JAXRS20ClientServerBookTest extends AbstractBusClientServerTestBase
     
         // Since JDK-21, HttpClient Implements AutoCloseable
         if (Runtime.version().feature() >= 21) { 
-            assertThat(captureHttpClientThreads.get(), lessThanOrEqualTo(expectedHttpClientThreads));
+            assertThat(captureHttpClientSelectorThreads.get(), lessThanOrEqualTo(expectedHttpClientSelectorThreads));
         }
     }
 
@@ -319,6 +333,26 @@ public class JAXRS20ClientServerBookTest extends AbstractBusClientServerTestBase
         assertEquals(124L, book.getId());
         assertEquals("b", r.getHeaderString("a"));
     }
+    
+    @Test
+    public void testRemoveProperty() {
+        String address = "http://localhost:" + PORT + "/bookstore/{a}";
+        Client client = ClientBuilder.newClient();
+        client.property("greeting", "hello");
+        client.property("greeting", null);
+        client.register((Object)ClientFilterClientAndConfigCheck.class);
+        client.register(new BTypeParamConverterProvider());
+        client.property("clientproperty", "somevalue");
+        WebTarget webTarget = client.target(address).path("{b}")
+            .resolveTemplate("a", "bookheaders").resolveTemplate("b", "simple");
+        Invocation.Builder builder = webTarget.request("application/xml").header("a", new BType());
+
+        Response r = builder.get();
+        Book book = r.readEntity(Book.class);
+        assertEquals(124L, book.getId());
+        assertEquals("b", r.getHeaderString("a"));
+    }
+    
     @Test
     public void testGetBookSpec() {
         String address = "http://localhost:" + PORT + "/bookstore/bookheaders/simple";
@@ -603,8 +637,7 @@ public class JAXRS20ClientServerBookTest extends AbstractBusClientServerTestBase
 
         String endpointAddress =
             "http://localhost:" + PORT + "/bookstore/collections";
-        WebClient wc = WebClient.create(endpointAddress,
-                                        Collections.singletonList(new JacksonXmlBindJsonProvider()));
+        WebClient wc = WebClient.create(endpointAddress);
         doTestPostGetCollectionGenericEntityAndType(wc, MediaType.APPLICATION_JSON_TYPE);
     }
 
@@ -1122,6 +1155,23 @@ public class JAXRS20ClientServerBookTest extends AbstractBusClientServerTestBase
             + "jakarta.ws.rs.ext.Provider,jakarta.ws.rs.Consumes}"));
     }
     
+    @Test
+    public void testGetCookies() throws Exception {
+        final WebTarget target = ClientBuilder
+            .newClient()
+            .property("org.apache.cxf.http.cookie.separator", ";")
+            .target("http://localhost:" + PORT + "/bookstore/cookies");
+
+        @SuppressWarnings("unchecked")
+        final Response response = target
+            .request().accept("application/json")
+            .cookie(new Cookie("a", "1"))
+            .cookie(new Cookie("b", "2"))
+            .get();
+
+        assertThat(response.getHeaderString(HttpHeaders.SET_COOKIE), equalTo("$Version=1;a=1; $Version=1;b=2"));
+    }
+
     private static final class ReplaceBodyFilter implements ClientRequestFilter {
 
         @Override
